@@ -50,10 +50,10 @@ pub struct OASISWriterConfig {
     table_offsets_at_start: bool,
 
     /// Tells if IDs are given implicitly by a counter or are explicitly written in the file.
-    explicit_ids: bool,
+    pub explicit_ids: bool,
 
     /// Type of integrity checksum used while writing the OASIS stream. Default is `None` (0).
-    validation_scheme: OASISValidationScheme,
+    pub validation_scheme: OASISValidationScheme,
 }
 
 #[derive(Copy, Clone, Debug, Default)]
